package com.ruoyi.asset.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.asset.domain.TbAssetCategory;
import com.ruoyi.asset.service.ITbAssetCategoryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产分类Controller
 * 
 * @author 原动力
 * @date 2023-05-15
 */
@RestController
@RequestMapping("/asset/category")
public class TbAssetCategoryController extends BaseController
{
    @Autowired
    private ITbAssetCategoryService tbAssetCategoryService;

    /**
     * 查询资产分类列表
     */
    @PreAuthorize("@ss.hasPermi('asset:category:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAssetCategory tbAssetCategory)
    {
        startPage();
        List<TbAssetCategory> list = tbAssetCategoryService.selectTbAssetCategoryList(tbAssetCategory);
        return getDataTable(list);
    }

    /**
     * 导出资产分类列表
     */
    @PreAuthorize("@ss.hasPermi('asset:category:export')")
    @Log(title = "资产分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAssetCategory tbAssetCategory)
    {
        List<TbAssetCategory> list = tbAssetCategoryService.selectTbAssetCategoryList(tbAssetCategory);
        ExcelUtil<TbAssetCategory> util = new ExcelUtil<TbAssetCategory>(TbAssetCategory.class);
        util.exportExcel(response, list, "资产分类数据");
    }

    /**
     * 获取资产分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('asset:category:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbAssetCategoryService.selectTbAssetCategoryById(id));
    }

    /**
     * 新增资产分类
     */
    @PreAuthorize("@ss.hasPermi('asset:category:add')")
    @Log(title = "资产分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAssetCategory tbAssetCategory)
    {
        return toAjax(tbAssetCategoryService.insertTbAssetCategory(tbAssetCategory));
    }

    /**
     * 修改资产分类
     */
    @PreAuthorize("@ss.hasPermi('asset:category:edit')")
    @Log(title = "资产分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAssetCategory tbAssetCategory)
    {
        return toAjax(tbAssetCategoryService.updateTbAssetCategory(tbAssetCategory));
    }

    /**
     * 删除资产分类
     */
    @PreAuthorize("@ss.hasPermi('asset:category:remove')")
    @Log(title = "资产分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetCategoryService.deleteTbAssetCategoryByIds(ids));
    }
}
