package com.ruoyi.change.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.change.domain.TbAssetAllocationDetail;
import com.ruoyi.change.service.ITbAssetAllocationDetailService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产调拨明细Controller
 * 
 * @author 原动力
 * @date 2023-05-15
 */
@RestController
@RequestMapping("/change/allocationDetail")
public class TbAssetAllocationDetailController extends BaseController
{
    @Autowired
    private ITbAssetAllocationDetailService tbAssetAllocationDetailService;

    /**
     * 查询资产调拨明细列表
     */
    @PreAuthorize("@ss.hasPermi('change:allocationDetail:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAssetAllocationDetail tbAssetAllocationDetail)
    {
        startPage();
        List<TbAssetAllocationDetail> list = tbAssetAllocationDetailService.selectTbAssetAllocationDetailList(tbAssetAllocationDetail);
        return getDataTable(list);
    }

    /**
     * 导出资产调拨明细列表
     */
    @PreAuthorize("@ss.hasPermi('change:allocationDetail:export')")
    @Log(title = "资产调拨明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAssetAllocationDetail tbAssetAllocationDetail)
    {
        List<TbAssetAllocationDetail> list = tbAssetAllocationDetailService.selectTbAssetAllocationDetailList(tbAssetAllocationDetail);
        ExcelUtil<TbAssetAllocationDetail> util = new ExcelUtil<TbAssetAllocationDetail>(TbAssetAllocationDetail.class);
        util.exportExcel(response, list, "资产调拨明细数据");
    }

    /**
     * 获取资产调拨明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('change:allocationDetail:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbAssetAllocationDetailService.selectTbAssetAllocationDetailById(id));
    }

    /**
     * 新增资产调拨明细
     */
    @PreAuthorize("@ss.hasPermi('change:allocationDetail:add')")
    @Log(title = "资产调拨明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAssetAllocationDetail tbAssetAllocationDetail)
    {
        return toAjax(tbAssetAllocationDetailService.insertTbAssetAllocationDetail(tbAssetAllocationDetail));
    }

    /**
     * 修改资产调拨明细
     */
    @PreAuthorize("@ss.hasPermi('change:allocationDetail:edit')")
    @Log(title = "资产调拨明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAssetAllocationDetail tbAssetAllocationDetail)
    {
        return toAjax(tbAssetAllocationDetailService.updateTbAssetAllocationDetail(tbAssetAllocationDetail));
    }

    /**
     * 删除资产调拨明细
     */
    @PreAuthorize("@ss.hasPermi('change:allocationDetail:remove')")
    @Log(title = "资产调拨明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetAllocationDetailService.deleteTbAssetAllocationDetailByIds(ids));
    }
}
