package com.ruoyi.change.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.change.domain.TbAssetLend;
import com.ruoyi.change.service.ITbAssetLendService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产借出Controller
 * 
 * @author 原动力
 * @date 2023-05-15
 */
@RestController
@RequestMapping("/change/assetLend")
public class TbAssetLendController extends BaseController
{
    @Autowired
    private ITbAssetLendService tbAssetLendService;

    /**
     * 查询资产借出列表
     */
    @PreAuthorize("@ss.hasPermi('change:assetLend:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAssetLend tbAssetLend)
    {
        startPage();
        List<TbAssetLend> list = tbAssetLendService.selectTbAssetLendList(tbAssetLend);
        return getDataTable(list);
    }

    /**
     * 导出资产借出列表
     */
    @PreAuthorize("@ss.hasPermi('change:assetLend:export')")
    @Log(title = "资产借出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAssetLend tbAssetLend)
    {
        List<TbAssetLend> list = tbAssetLendService.selectTbAssetLendList(tbAssetLend);
        ExcelUtil<TbAssetLend> util = new ExcelUtil<TbAssetLend>(TbAssetLend.class);
        util.exportExcel(response, list, "资产借出数据");
    }

    /**
     * 获取资产借出详细信息
     */
    @PreAuthorize("@ss.hasPermi('change:assetLend:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbAssetLendService.selectTbAssetLendById(id));
    }

    /**
     * 新增资产借出
     */
    @PreAuthorize("@ss.hasPermi('change:assetLend:add')")
    @Log(title = "资产借出", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAssetLend tbAssetLend)
    {
        return toAjax(tbAssetLendService.insertTbAssetLend(tbAssetLend));
    }

    /**
     * 修改资产借出
     */
    @PreAuthorize("@ss.hasPermi('change:assetLend:edit')")
    @Log(title = "资产借出", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAssetLend tbAssetLend)
    {
        return toAjax(tbAssetLendService.updateTbAssetLend(tbAssetLend));
    }

    /**
     * 删除资产借出
     */
    @PreAuthorize("@ss.hasPermi('change:assetLend:remove')")
    @Log(title = "资产借出", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetLendService.deleteTbAssetLendByIds(ids));
    }
}
