package com.ruoyi.change.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.change.domain.TbAssetOrder;
import com.ruoyi.change.service.ITbAssetOrderService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产单据Controller
 * 
 * @author 原动力
 * @date 2023-05-15
 */
@RestController
@RequestMapping("/change/order")
public class TbAssetOrderController extends BaseController
{
    @Autowired
    private ITbAssetOrderService tbAssetOrderService;

    /**
     * 查询资产单据列表
     */
    @PreAuthorize("@ss.hasPermi('change:order:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAssetOrder tbAssetOrder)
    {
        startPage();
        List<TbAssetOrder> list = tbAssetOrderService.selectTbAssetOrderList(tbAssetOrder);
        return getDataTable(list);
    }

    /**
     * 导出资产单据列表
     */
    @PreAuthorize("@ss.hasPermi('change:order:export')")
    @Log(title = "资产单据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAssetOrder tbAssetOrder)
    {
        List<TbAssetOrder> list = tbAssetOrderService.selectTbAssetOrderList(tbAssetOrder);
        ExcelUtil<TbAssetOrder> util = new ExcelUtil<TbAssetOrder>(TbAssetOrder.class);
        util.exportExcel(response, list, "资产单据数据");
    }

    /**
     * 获取资产单据详细信息
     */
    @PreAuthorize("@ss.hasPermi('change:order:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbAssetOrderService.selectTbAssetOrderById(id));
    }

    /**
     * 新增资产单据
     */
    @PreAuthorize("@ss.hasPermi('change:order:add')")
    @Log(title = "资产单据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAssetOrder tbAssetOrder)
    {
        return toAjax(tbAssetOrderService.insertTbAssetOrder(tbAssetOrder));
    }

    /**
     * 修改资产单据
     */
    @PreAuthorize("@ss.hasPermi('change:order:edit')")
    @Log(title = "资产单据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAssetOrder tbAssetOrder)
    {
        return toAjax(tbAssetOrderService.updateTbAssetOrder(tbAssetOrder));
    }

    /**
     * 删除资产单据
     */
    @PreAuthorize("@ss.hasPermi('change:order:remove')")
    @Log(title = "资产单据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetOrderService.deleteTbAssetOrderByIds(ids));
    }
}
