package com.ruoyi.inventory.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.inventory.domain.TbInventoryDetail;
import com.ruoyi.inventory.service.ITbInventoryDetailService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产盘点明细Controller
 * 
 * @author ydl
 * @date 2023-06-01
 */
@RestController
@RequestMapping("/inventory/detail")
public class TbInventoryDetailController extends BaseController
{
    @Autowired
    private ITbInventoryDetailService tbInventoryDetailService;

    /**
     * 查询资产盘点明细列表
     */
    @PreAuthorize("@ss.hasPermi('inventory:detail:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbInventoryDetail tbInventoryDetail)
    {
        startPage();
        List<TbInventoryDetail> list = tbInventoryDetailService.selectTbInventoryDetailList(tbInventoryDetail);
        return getDataTable(list);
    }

    /**
     * 导出资产盘点明细列表
     */
    @PreAuthorize("@ss.hasPermi('inventory:detail:export')")
    @Log(title = "资产盘点明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbInventoryDetail tbInventoryDetail)
    {
        List<TbInventoryDetail> list = tbInventoryDetailService.selectTbInventoryDetailList(tbInventoryDetail);
        ExcelUtil<TbInventoryDetail> util = new ExcelUtil<TbInventoryDetail>(TbInventoryDetail.class);
        util.exportExcel(response, list, "资产盘点明细数据");
    }

    /**
     * 获取资产盘点明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('inventory:detail:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbInventoryDetailService.selectTbInventoryDetailById(id));
    }

    /**
     * 新增资产盘点明细
     */
    @PreAuthorize("@ss.hasPermi('inventory:detail:add')")
    @Log(title = "资产盘点明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbInventoryDetail tbInventoryDetail)
    {
        return toAjax(tbInventoryDetailService.insertTbInventoryDetail(tbInventoryDetail));
    }

    /**
     * 修改资产盘点明细
     */
    @PreAuthorize("@ss.hasPermi('inventory:detail:edit')")
    @Log(title = "资产盘点明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbInventoryDetail tbInventoryDetail)
    {
        return toAjax(tbInventoryDetailService.updateTbInventoryDetail(tbInventoryDetail));
    }

    /**
     * 删除资产盘点明细
     */
    @PreAuthorize("@ss.hasPermi('inventory:detail:remove')")
    @Log(title = "资产盘点明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbInventoryDetailService.deleteTbInventoryDetailByIds(ids));
    }
}
